@@ -221,7 +221,7 @@ void BacktraceWidget::loadData()
         }
 
         // highlight if possible
-        if (m_btGenerator->debugger().codeName() == QLatin1String("gdb")) {
+        if (m_btGenerator->debuggerIsGDB()) {
             KSyntaxHighlighting::Repository repository;
             m_highlighter = new KSyntaxHighlighting::SyntaxHighlighter(ui.m_backtraceEdit->document());
             m_highlighter->setTheme((palette().color(QPalette::Base).lightness() < 128) ? repository.defaultTheme(KSyntaxHighlighting::Repository::DarkTheme)
@@ -276,7 +276,7 @@ void BacktraceWidget::loadData()
                                                        QLatin1String("#missingDebugPackages")));
                 ui.m_installDebugButton->setVisible(true);
                 // Retrieve the libraries with missing debug info
-                QStringList missingLibraries = btParser->librariesWithMissingDebugSymbols().values();
+                const QStringList missingLibraries = btParser->librariesWithMissingDebugSymbols();
                 m_debugPackageInstaller->setMissingLibraries(missingLibraries);
             } else {
                 // No automated method to install the missing debug info
@@ -322,7 +322,7 @@ void BacktraceWidget::loadData()
                                                "<strong>You need to first install the debugger "
                                                "application (%1) then click the <interface>Reload"
                                                "</interface> button.</strong>",
-                                               m_btGenerator->debugger().displayName()));
+                                               m_btGenerator->debuggerName()));
     }
 
     ui.m_reloadBacktraceButton->setEnabled(true);
@@ -402,7 +402,7 @@ void BacktraceWidget::extraDetailsLinkActivated(QString link)
     } else if (link == QLatin1String("#missingDebugPackages")) {
         BacktraceParser *btParser = m_btGenerator->parser();
 
-        QStringList missingDbgForFiles = btParser->librariesWithMissingDebugSymbols().values();
+        QStringList missingDbgForFiles = btParser->librariesWithMissingDebugSymbols();
         missingDbgForFiles.insert(0, DrKonqi::crashedApplication()->executable().absoluteFilePath());
 
         // HTML message
